@@ -11,6 +11,8 @@ ADDRESS_LINES = [
 ADDRESS = ', '.join(ADDRESS_LINES)
 PHONE = "(703) 282-4142"
 SITE_URL = "https://nickderobertis.com"
+SOFTWARE_URL = f"{SITE_URL}/software"
+RESEARCH_URL = f"{SITE_URL}/research"
 SITE_DISPLAY = "nickderobertis.com"
 STYLED_SITE = pl.Hyperlink(
     SITE_URL,
