@@ -41,6 +41,19 @@ FIN_MODEL_COURSE_CATEGORIES = [
     CategoryModel('Discounted cash flow (DCF) valuation', parents=(CORPORATE_VALUATION_CATEGORY,)),
 ]
 
+FM_EXCEL_CATEGORY = CategoryModel('Excel')
+
+FIN_MODEL_COURSE_PREREQ_CATEGORIES = [
+    CategoryModel('Algebra'),
+    FM_EXCEL_CATEGORY,
+    CategoryModel('Data entry, editing', parents=(FM_EXCEL_CATEGORY,)),
+    CategoryModel('Number and cell formatting', parents=(FM_EXCEL_CATEGORY,)),
+    CategoryModel('How to work with formulas, and knowledge of common math formulas', parents=(FM_EXCEL_CATEGORY,)),
+    CategoryModel('Cell references - fixed and relative, when to use each and why', parents=(FM_EXCEL_CATEGORY,)),
+    CategoryModel('Managing worksheets and workbooks', parents=(FM_EXCEL_CATEGORY,)),
+    CategoryModel('Graphs, charts', parents=(FM_EXCEL_CATEGORY,)),
+]
+
 DEBT_COURSE_CATEGORIES = [
     *DEBT_COURSE_MAIN_CATEGORIES,
 
