@@ -434,6 +434,11 @@ _SKILLS: List[SkillModel] = [
         experience=SkillExperience('5/14/2020', hours_per_week=0, one_time_hours=20),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
+    SkillModel(
+        'Svelte', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience('1/15/2021', hours_per_week=0, one_time_hours=40),
+        priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
+    ),
     SkillModel(
         'Docker', 4, parents=(DEV_OPS_SKILL,), flexible_case=False,
         experience=SkillExperience('8/1/2016', hours_per_week=2),
