@@ -1057,3 +1057,24 @@ TSINGHUA = UniversityModel(
     ]
 )
 TSINGHUA_TARGET = ApplicationTarget(TSINGHUA, AP)
+
+NATIONAL_TAIWAN = UniversityModel(
+    'National Taiwan University',
+    'Taipei, Taiwan',
+    abbreviation='NTU',
+    address_lines=[
+        'Department of Finance',
+        'National Taiwan University',
+        'No.1, Section 4, Roosevelt Road',
+        'Taipei 106, Taiwan',
+    ],
+    city='Taipei',
+    country='Taiwan',
+    characteristics=[
+        OrganizationCharacteristics.INTERNATIONAL,
+        OrganizationCharacteristics.LARGE_CITY,
+        OrganizationCharacteristics.WARM_WEATHER,
+    ],
+)
+NATIONAL_TAIWAN_PERSON = HiringManager('Recruiting Chair', is_person=False)
+NATIONAL_TAIWAN_TARGET = ApplicationTarget(NATIONAL_TAIWAN, AP, person=NATIONAL_TAIWAN_PERSON)
\ No newline at end of file
