@@ -63,6 +63,25 @@ class Syllabus(pl.Template):
     @property
     def course_materials_section(self) -> pl.Section:
         contents = []
+        if self.model.website_url is not None:
+            contents.append(
+                pl.SubSection(
+                    [
+                        pl.TextColor(
+                            pl.Underline(
+                                pl.Hyperlink(self.model.website_url, self.model.website_url)
+                            ),
+                            'blue'
+                        ),
+                        pl.UnorderedList([
+                            'The course website includes all of the materials for the course, including the '
+                            'course schedule, lecture videos, lab exercises, practice problems, and projects.'
+                        ])
+                    ],
+                    title='Course Website'
+                )
+            )
+
         if self.model.textbook is not None:
             contents.append(
                 pl.SubSection(
